/*
 * a_app2d.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * Base class for application object (handles main loop and gfx setup)
 * 2D version (ddraw, sdl, etc.)
 *
 */

#ifndef APP2D_HPP
#define APP2D_HPP

#include "app_base.hpp"

//
// Structure to describe available full screen display modes
//
struct DisplayMode {
	int width;
	int height;
	int colour_depth;	// in bits (8 16 or 24)
};



//
// The main App2D class.
//

class App2D : public AppBase {
public:
	//
	// Full screen displays
	//

	// Enumerate the available full screen display modes.
	// findDisplayModes returns number of modes found which
	// can then be accessed with getMode.
	virtual int findDisplayModes() = 0;
	virtual const DisplayMode & getDisplayMode(int n) = 0; // n is from 0 to num_modes-1

	// Open a display in full-screen using the given display mode.
	// title is the window title (appears on the Windows taskbar)
	virtual void openFullScreen(int mode_num, const char *title) = 0;

	//
	// Windowed displays
	//
	
	// Open a windowed display at given x,y,width,height and with given window title.
	virtual void openWindowed(int x, int y, int width, int height, const char* title) = 0;


};


#endif   // A_APP2D_HPP
