/*
 * draw.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * Contains code for drawing various bits of the in-game displays.
 *
 */

#ifndef DRAW_HPP
#define DRAW_HPP

#include "graphic_element.hpp"
#include "map_support.hpp"

#include "boost/shared_ptr.hpp"
using namespace boost;

#include <map>
#include <vector>
using namespace std;

class ColourChange;
class Creature;
class Display;
class DungeonMap;
class Entity;
class Graphic;
class MapCoord;


class DrawUI {
public:
	// Draw backpack entries (items).
	// This is called once per backpack 'slot' (i.e. item type).
	static void drawBackpackEntry(Display &display, int left, int bottom, int right, int top,
								  int slot, const Graphic *gfx,
								  int no_carried, int no_max);
	
	// Draw a text message over a certain square
	// Bl and Tr give the dungeon rectangle (as above)
	// Sq_rel_x and Sq_rel_y give the square position
	// W and H give the room dimensions (in squares)
	// Message is the text to be displayed.
	static void drawMessage(Display &display, int bl_x, int bl_y, int tr_x, int tr_y,
							int sq_rel_x, int sq_rel_y, int w, int h, const string &message);

	
	// Draw the menu
	static void drawMenu(Display &display, int bl_x, int bl_y,
						 const Graphic * gfx_centre, const Graphic * gfx_empty,
						 const Graphic * gfx_highlight,
						 const Graphic * gfx_north, const Graphic * gfx_east,
						 const Graphic * gfx_south, const Graphic * gfx_west,
						 bool highlight, MapDirection highlight_dir);

private:
	static void drawMenuItem(Display &, const Graphic *, const Graphic *, int, int);
};

#endif
