/*
 * game_client.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * GameClient is responsible for receiving network packets and changing them
 * into game commands.
 *
 */

#ifndef GAME_CLIENT_HPP
#define GAME_CLIENT_HPP

#include "binary_io/binary_io.hpp"
#include "map_support.hpp"

#include <iostream> // not <iosfwd>, because need inheritance relationship istream -> iostream
#include <utility>
using namespace std;

class Anim;
class ClientConfig;
class Control;
class Graphic;
class LocalDungeonView;
class Overlay;


class GameClient {
public:
	// Note: Ctor assumes that we have received all config data already, and that
	// the stream is clear for sending/receiving game data. (Nothing is sent or received
	// until the first call to update, though.)
	GameClient(iostream &connection_to_server, LocalDungeonView &client_dview,
			   ClientConfig &conf);

	// Update by moving GVT forward, and then receiving commands from the network.
	// Note we accept a *delta* to be added to GVT, not an absolute new GVT.
	void update(int delta_gvt);

	// Query whether the game is over (we have received a C_WIN_GAME, C_LOSE_GAME or
	// C_QUIT_GAME).
	bool isGameOver() const { return game_over; }
	bool isGameQuit() const { return game_quit; }
	
	// get gvt
	int getGVT() const { return gvt; }
	
private:
	int recvCommandNo();
	int recvRoomNo() { return BinReadUbyte(str); }
	MapCoord recvMapCoord();
	void recvRoomCoord(int &x, int &y) { recvNibbles(x, y); x--; y--; }
	int recvSpeed() { return BinReadUword(str); }
	void recvTileInfo(int &d, int &c, bool &cc);
	const Anim * recvAnimPtr();
	const Control * recvControlPtr();
	pair<const Control*, bool> recvControlPlusBool();
	const Graphic * recvGraphicPtr();
	const Overlay * recvOverlayPtr();
	string recvString();
	void recvNibbles(int &, int &);
	void sendGameOverMsg();
	void sendControl(const Control *ctrl);
	void receiveCommands();

private:
	iostream &str;
	LocalDungeonView &dview;
	ClientConfig &conf;
	int gvt;
	const Control *last_sent_ctrl;
	bool game_over, game_quit;
};

#endif
