/*
 * in_game_screen.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * InGameScreen
 * --- runs the game
 * Goes back to MenuScreen when done
 *
 */

#ifndef IN_GAME_SCREEN_HPP
#define IN_GAME_SCREEN_HPP

#include "boost/shared_ptr.hpp"
using namespace boost;

#include "app/app2d.hpp"
#include "knights_game.hpp"

class GameClient;
class GameServer;
class LocalDungeonView;
class MenuSelections;
class RemoteDungeonView;


void SetupInGameScreen(const UsefulStuff &u, const MenuSelections & msel);
void StopInGameScreen(const UsefulStuff &u);

// I suppose that we do not need the InGameScreen class definition in the header
// file (it could go in the .cpp file). But I'm not going to bother changing it now...

class InGameScreen : public AppObserver {
public:
	InGameScreen(const UsefulStuff &u, const MenuSelections &ms);
	virtual ~InGameScreen();
	
	virtual void render();
	virtual void update();
	virtual void mouseDown(int,int,bool);
	virtual void key(Keycode k);
	
private:
	void serverSetup(const MenuSelections &msel);
	bool tryClientSetup();
	
private:
	UsefulStuff us;
	shared_ptr<GameServer> game_server;
	shared_ptr<GameClient> game_client;
	shared_ptr<LocalDungeonView> ldv1, ldv2;
	shared_ptr<RemoteDungeonView> rdv1;
	bool first_update, sent_ready_yet, knights_spawned_yet;
	int prev_update_time;

	enum GameStage { SETUP_STAGE, HANDSHAKE_STAGE, INGAME_STAGE, GAMEOVER_STAGE };
	GameStage stage;
};

#endif
