/*
 * keyboard_controller.cpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "keyboard_controller.hpp"

class KeyboardObserver : public AppObserver {
public:
	explicit KeyboardObserver(KeyboardController &kc_) : kc(kc_) { }
	virtual void key(Keycode k);
	virtual void keyUp(Keycode k);

private:
	KeyboardController &kc;
};

KeyboardController::KeyboardController(Keycode u, Keycode r, Keycode d,
									   Keycode l, Keycode f, Keycode s, App2D &a)
	: obs(new KeyboardObserver(*this)),
	  app(a), up_key(u), right_key(r), down_key(d), left_key(l), fire_key(f), suicide_key(s),
	  up(false), right(false), down(false), left(false), fire(false), suicide(false)
{
	for (int i=0; i<12; ++i) cheat[i] = false;
	app.addObserver(obs.get());
}

KeyboardController::~KeyboardController()
{
	app.rmObserver(obs.get());
}

void KeyboardController::get(MapDirection &dir, bool &centred, bool &fire_held,
							 bool &suicide_held) const
{
	fire_held = fire;
	suicide_held = suicide;
	centred = !up && !right && !down && !left;
	if (!centred) {
		if (up) dir = D_NORTH;
		else if (right) dir = D_EAST;
		else if (down) dir = D_SOUTH;
		else dir = D_WEST;
	}
}

int KeyboardController::getCheatKey() const
{
	for (int i=0; i<12; ++i) {
		if (cheat[i]) {
			return i+1;
		}
	}
	return 0;
}

void KeyboardObserver::key(Keycode k)
{
	if (k == kc.up_key) kc.up = true;
	else if (k == kc.right_key) kc.right = true;
	else if (k == kc.down_key) kc.down = true;
	else if (k == kc.left_key) kc.left = true;
	else if (k == kc.fire_key) kc.fire = true;
	else if (k == kc.suicide_key) kc.suicide = true;
	else if (k >= KC_F1 && k <= KC_F12) kc.cheat[k-KC_F1] = true;
}

void KeyboardObserver::keyUp(Keycode k)
{
	if (k == kc.up_key) kc.up = false;
	else if (k == kc.right_key) kc.right = false;
	else if (k == kc.down_key) kc.down = false;
	else if (k == kc.left_key) kc.left = false;
	else if (k == kc.fire_key) kc.fire = false;
	else if (k == kc.suicide_key) kc.suicide = false;
	else if (k >= KC_F1 && k <= KC_F12) kc.cheat[k-KC_F1] = false;
}
