/*
 * main.cpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * The main routine. Sets up a couple of error handlers etc then calls into knights_game.cpp.
 *
 */

#include "misc.hpp"

#include "knights_game.hpp"

//----------------
 
// this controls whether to catch exceptions from main & print an
// error message, or else to rely on the compiler to print enough info
// about uncaught exceptions
#define CATCH_EXCEPTIONS

//----------------

#ifdef CATCH_EXCEPTIONS
#include <iostream>
using namespace std;
#endif

#ifdef _WIN32_WCE
extern "C" {
#include <sys/wcetrace.h>
}
#endif


extern "C" {  // needed for SDL I think
int main(int argc, char **argv)
{

#ifdef _WIN32_WCE
	// Turn off annoying trace file generation in NEWLIB
	// (because it slows everything down and wastes memory).
	WCETRACESET(0);
#endif

#ifdef CATCH_EXCEPTIONS
	try {
#endif

		// Get resource dir.
		// (TODO) We need a way of finding the resource dir in a portable way. Eg we probably
		// want a "GetExeDirectory" type routine, or at least some sort of registry key so
		// that we can find our own data directory .....
		// For now we look in "knights_data" (you have to cd to the appropriate place for
		// this to work) or else specify a full path on the command line.
		string rdir;
		if (argc>1) {
			rdir = argv[1];
		} else {
			rdir = "knights_data";
		}
		

		// Run the game itself:
		RunKnights(rdir);
		
#ifdef CATCH_EXCEPTIONS
	} catch (exception &e) {
		cerr << "ERROR: Caught exception:" << endl;
		cerr << e.what() << endl;
	} catch (...) {
		cerr << "ERROR: Unknown exception caught" << endl;
	}
#endif

	return 0;
}

} // extern "C"


//---------------------

//
// boost::assertion_failed
//

#ifdef BOOST_ENABLE_ASSERT_HANDLER

#include "boost/assert.hpp"

void boost::assertion_failed(char const * expr, char const * function, char const * file, long line) // user defined
{
	cout << "<< BOOST ASSERTION FAILED >> " << endl;
	cout << file << ":" << line << ": " << function << ": " << expr << endl;
	exit(1);
}

#endif
