/*
 * p_graphic.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 */

#ifndef P_GRAPHIC_HPP
#define P_GRAPHIC_HPP

#include "exception_base.hpp"

#include <iosfwd>
#include <string>
using namespace std;

// Graphic is just an incomplete type as far as main program is concerned
class Graphic;

// Create graphics
// x,y are "handle" position.
// r,g,b specify transparency colour (0--255). Set r to a negative number for no transparency.
// Throws "GraphicLoadFailed" if there is a problem, otherwise always returns non-null.
Graphic * CreateGraphic(const string &filename, int x, int y, int r, int g, int b);

// Get size of graphics, and "ID number" (each graphic is given a unique ID starting from 1)
int GetWidth(const Graphic &);
int GetHeight(const Graphic &);
int GetID(const Graphic &);

// Delete graphics
void DeleteGraphic(Graphic *);

// Serialization [also sets an ID number on the graphic]
void SerializeGraphic(ostream &, Graphic &, int id);
Graphic * CreateGraphicFromStream(istream &);

#endif
