/*
 * sdl_graphic.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * SDL implementation of Graphic, CreateGraphic and DestroyGraphic
 *
 */

#ifndef SDL_GRAPHIC_HPP
#define SDL_GRAPHIC_HPP

#include "colour_change.hpp"
#include "graphic.hpp"

#include <SDL.h>

class Graphic {
public:
	// load from file with colour key (transparent colour) or -1 to disable
	// (the colour values go from 0 to 255.)
	Graphic(const string &rname_, int r, int g, int b, int hx, int hy);

	// recolour an existing graphic ...
	Graphic(const Graphic &original, const ColourChange &cc);
	
	// dtor (unloads the surface)
	~Graphic();

	// blit to screen at a certain position
	// (this is used to implement Display::drawGraphic)
	void blit(SDL_Surface *dest, int sdl_x, int sdl_y, bool darken) const;

	int getWidth() const { return surface ? surface->w : 0; }
	int getHeight() const { return surface ? surface->h : 0; }
	int getID() const { return id; }

	friend void SerializeGraphic(ostream &str, Graphic &g, int id);
	friend Graphic * CreateGraphicFromStream(istream &);
	
private:
	void load() const;
	void unload() const;
	void makeDarkSurface() const;

private:
	// invariant: surface==0 => dark_surface==0
	mutable SDL_Surface *surface;
	mutable SDL_Surface *dark_surface;
	int hx, hy, r, g, b;
	int id;
	string rname;
	ColourChange col_chg;
	mutable bool need_reload;
};

#endif

