/*
 * sdl_graphic_cache.cpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "misc.hpp"

#include "sdl_graphic.hpp"
#include "sdl_graphic_cache.hpp"

SdlGraphicCache g_sdl_graphic_cache;

SdlGraphicCache::SdlGraphicCache()
{
	max_cache_size = 100;
}

SdlGraphicCache::~SdlGraphicCache()
{
	for (list<CacheEntry>::iterator it = cache.begin(); it != cache.end(); ++it) {
		delete it->recoloured;
	}
}

Graphic * SdlGraphicCache::getGraphicWithCC(const Graphic &original,
											const ColourChange &cc)
{
	// Hmm, this may be a little slow -- implement a multi_index approach?
	for (list<CacheEntry>::iterator it = cache.begin(); it != cache.end(); ++it) {
		if (it->original == &original && it->cc == cc) {
			// move it to front of list
			cache.push_front(*it);
			cache.erase(it);
			return cache.front().recoloured;
		}
	}

	// Entry wasn't found in the cache. Make a new entry
	CacheEntry ce;
	ce.original = &original;
	ce.cc = cc;
	ce.recoloured = new Graphic(original, cc);
	cache.push_front(ce);
	++cache_size;
	while (cache_size > max_cache_size) {
		delete cache.back().recoloured;
		cache.pop_back();
		--cache_size;
	}
	return ce.recoloured;
}
