/*
 * sdl_graphic_cache.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * This is used to cache 'colour-changed' graphics.
 *
 */

#ifndef SDL_GRAPHIC_CACHE_HPP
#define SDL_GRAPHIC_CACHE_HPP

#include "colour_change.hpp"

#include <list>
using namespace std;

class Graphic;

class SdlGraphicCache {
public:
	SdlGraphicCache();
	~SdlGraphicCache();
	
	// Input: an 'original' graphic
	// Output: a new graphic with the colours changed
	// Note all graphics should be used immediately before getting any other graphic from
	// the cache, since getGraphicWithCC can delete cached graphics.
	// All cached graphics are deleted in the dtor.
	Graphic * getGraphicWithCC(const Graphic &original, const ColourChange &cc);

private:
	SdlGraphicCache(const SdlGraphicCache&);  // not defined
	void operator=(const SdlGraphicCache&);   // not defined
	
	struct CacheEntry {
		const Graphic * original;
		Graphic * recoloured;
		ColourChange cc;
	};
	list<CacheEntry> cache;  // most-recently-used first
	int cache_size, max_cache_size;
};

// Global access point
extern SdlGraphicCache g_sdl_graphic_cache;

#endif
