/*
 * potion_renderer.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * This draws the potion bottle, showing Knight's health and current magic.
 * 
 */

#ifndef POTION_RENDERER_HPP
#define POTION_RENDERER_HPP

#include "potion_magic.hpp"

#include <vector>
using namespace std;

class ClientConfig;
class Display;
class Graphic;

class PotionRenderer {
public:
	//
	// setup
	//
	PotionRenderer();
	
	// Graphics, to be added in order of increasing health
	// (first for 0 health, second for 1 hitpoint, 3rd for 2 hitpoints etc)
	void addGraphic(const Graphic *);

	// Colours, to be added in order of PotionMagics.
	void addColour(int r, int g, int b);

	//
	// drawing
	//
	void draw(int gvt, Display &, int health, PotionMagic magic, bool poison_immunity,
			  int left, int bottom) const;

	//
	// serialization... (Graphics must have been serialized first.)
	//
	void serialize(ostream &str) const;
	PotionRenderer(istream &str, ClientConfig &conf);
	
private:
	int def_r, def_g, def_b;
	vector<const Graphic *> gfx;
	vector<ColourChange> colours;
};

#endif
