/*
 * skull_renderer.cpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 */

#include "misc.hpp"

#include "binary_io/binary_io.hpp"
#include "client_config.hpp"
#include "platform/display.hpp"
#include "platform/graphic.hpp"
#include "skull_renderer.hpp"

void SkullRenderer::addGraphic(const Graphic *g)
{
	gfx.push_back(g);
}

void SkullRenderer::addColumn(int c)
{
	columns.push_back(c);
}

void SkullRenderer::addRow(int r)
{
	rows.push_back(r);
}

void SkullRenderer::draw(Display &dpy, int nsk, int left, int bottom) const
{
	dpy.clearClipRectangle();
	int r = 0;
	int c = 0;
	while (nsk > 0) {
		const int x = columns[c] + left;
		const int y = rows[r] + bottom;
		const int n = min(nsk, int(gfx.size()));
		dpy.drawGraphic(x, y, *gfx[n-1]);
		nsk -= n;
		++r;
		if (r >= rows.size()) {
			r = 0;
			++c;
			if (c >= columns.size()) {
				// maximum number of skulls has been reached
				break;
			}
		}
	}
}

void SkullRenderer::serialize(ostream &str) const
{
	BinWriteLong(str, gfx.size());
	for (int i=0; i<gfx.size(); ++i) {
		BinWriteLong(str, GetID(*gfx[i]));
	}
	BinWriteLong(str, rows.size());
	for (int i=0; i<rows.size(); ++i) BinWriteLong(str, rows[i]);
	BinWriteLong(str, columns.size());
	for (int i=0; i<columns.size(); ++i) BinWriteLong(str, columns[i]);
}

SkullRenderer::SkullRenderer(istream &str, ClientConfig &conf)
{
	int sz = BinReadLong(str);
	gfx.reserve(sz);
	for (int i=0; i<sz; ++i) gfx.push_back(conf.getGraphic(BinReadLong(str)));
	sz = BinReadLong(str);
	rows.reserve(sz);
	for (int i=0; i<sz; ++i) rows.push_back(BinReadLong(str));
	sz = BinReadLong(str);
	columns.reserve(sz);
	for (int i=0; i<sz; ++i) columns.push_back(BinReadLong(str));
}

