/*
 * skull_renderer.hpp
 *
 * Copyright (c) Stephen Thompson, 2006.
 * Licenced for non-commercial use only. See LICENCE.txt for details.
 *
 * Draws the columns of skulls, representing how many times you have died.
 *
 */

#ifndef SKULL_RENDERER_HPP
#define SKULL_RENDERER_HPP

class ClientConfig;
class Display;
class Graphic;

#include <iosfwd>
#include <vector>
using namespace std;

class SkullRenderer {
public:
	//
	// setup
	//
	
	SkullRenderer() { }
	
	// The skull graphics should be added in ascending order. The first has one skull
	// on it, the second has two skulls etc.
	void addGraphic(const Graphic *);

	// Pixel positions for the rows and columns. A graphic is drawn at (r,c) for each r and
	// each c, until all skulls have been drawn.
	void addColumn(int c);
	void addRow(int r);

	
	//
	// drawing
	//

	// draw (relative to given base position)
	void draw(Display &, int no_skulls, int left, int bottom) const;

	
	//
	// serialization
	//

	void serialize(ostream &) const;
	SkullRenderer(istream &, ClientConfig &);
	
private:
	vector<const Graphic *> gfx;
	vector<int> rows, columns;
};

#endif
